//------------------------------------------------------------------------------
//	$Id: nazicheck.js,v 1.10 2018/02/06 15:38:16 wolf Exp $
//------------------------------------------------------------------------------
//	Lizenz: WTF public license (see: http://www.wtfpl.net/)
//------------------------------------------------------------------------------
//	Quelle der Codes u.a.:
//	http://www.netz-gegen-nazis.de/artikel/rechtsextreme-sprachcodes-1144
//	Nein, keine Satire.
//	Ja, die meinen das ernst.
//------------------------------------------------------------------------------

var NAZI_SYMBOLS = {
	'124':	'1=A, 2=B, 4=D: Ausl\xe4nderbefreites Deutschland',
	'1347':	'13=M, 4=D, 7=G: Mit deutschem Gru\xdf',
	'14':	'14: 14 Worte "We must secure the existence of our race and a future for white children"\ndt.: "Wir m\xfcssen den Bestand unserer Rasse und die Zukunft wei\xdfer Kinder sichern."',
	'146':	'1=A, 4=D, 6=F: Auf den F\xfchrer',
	'18':	'1=A, 8=H: Adolf Hitler',
	'1919':	'19=S: SS = Schutzstaffel',
	'192':	'1=A, 9=I, 2=B: Adolf Is Back',
	'198':	'19=S, 8=H: Sieg Heil',
	'204':	'20. April:  Hitlers Geburtstag',
	'25':	'2=B, 5=E: Blut und Ehre',
	'28':	'2=B, 8=H: Blood and Honour',
	'311':	'311: 3/11 = Ku-Klux-Klan',
	'39':	'3=C, 9=I: Christliche Identit\xe4t',
	'420':	'April 20.:  Hitlers Geburtstag',
	'444':	'4=D: Deutschland den Deutschen',
	'74':	'7=G, 4=D: Gro\xdfdeutschland',
	'78':	'7=G, 8=H: G\xf6ring Hermann',
	'81':	'8=H, 1=A: Hitler Adolf',
	'828':	'2=B, 8=H: Heil, Blood and Honour',
	'84':	'8=H, 4=D: Heil Deutschland',
	'87':	'8=H, 7=G: Hermann G\xf6ring',
	'88':	'8=H: Heil Hitler',
	'C18':	'Combat18/Kampfgruppe Adolf Hitler',
	'H8':	'8=H: Wortspiel "Hate" und "Heil Hitler"',
	'HH':	'HH: Heil Hitler',
	'HJ':	'HJ: Hitlerjugend',
	'KZ':	'KZ: KonZentrationslager',
	'NS':	'NS: Nationalsozialismus',
	'SA':	'SA: Sturmabteilung',
	'SS':	'SS: Schutzstaffel'
};

window.addEventListener('load', function() {

	//----------------------------------------------------------------------
	//	create regular expression matching nazisymbols
	//----------------------------------------------------------------------

	var naziPattern = (function(table) {

		var elements = [];

		for (var tag in table) {

			elements.push (tag);
		}

		var rawPattern = elements.sort().reverse().join('|');

		return new RegExp('(' + rawPattern + ')');

	})(NAZI_SYMBOLS);

	//----------------------------------------------------------------------
	//	empty element
	//----------------------------------------------------------------------

	var removeChilds = function (element) {

		if (!element) return;
		while (element.firstChild) element.removeChild(element.firstChild);
	};

	//----------------------------------------------------------------------
	//	lookup nazi patterns in string,
	//		returns list of found patterns with explanation
	//----------------------------------------------------------------------

	var naziCheck = function (text) {

		var result = [];
		var match;

		while (match = text.match(naziPattern)) {

			var token = match[1];
			var index = text.indexOf(token);

			if (index>0) result.push({'s': text.substring(0, index)});

			result.push ({s: token, t: NAZI_SYMBOLS[token]});

			text = text.substring(index + token.length);
		}

		if (text.length>0) result.push({'s': text});

		return result;
	};

	//----------------------------------------------------------------------
	//	create div element from formatted result
	//----------------------------------------------------------------------

	var formatResult = function (result) {

		var divElement = document.createElement('div');

		for (var i in result) {

			var entry = result[i];

			var spanElement = document.createElement('span');
			spanElement.appendChild(document.createTextNode(entry.s||''));

			if (entry.t) {

				spanElement.title = entry.t;
				spanElement.className = 'nazicheck-hit';
			}

			divElement.appendChild(spanElement);
		}

		divElement.className = result.length>=2 || result[0].t?
			'nazicheck-hit' : 'nazicheck-nohit';

		return divElement;
	};

	//----------------------------------------------------------------------
	//	event handler: clear result
	//----------------------------------------------------------------------

	var clearResult = function(evt) {

		removeChilds (this.nextSibling);
	};

	//----------------------------------------------------------------------
	//	event handler: create result
	//----------------------------------------------------------------------

	var checkInput = function(evt) {

		var resultElement = this.nextSibling;
		removeChilds(resultElement);

		var value = this.value.replace(/^\s+/,'').replace(/\s+$/,'');
		if (!value) return;

		var values = this.tagName.toLowerCase()=='textarea'?
					value.split(/\s+/) : [value];

		for (var v=0; v<values.length; v++) {

			var result = naziCheck(values[v]);
			if (!result || !result.length) continue;

			resultElement.appendChild(formatResult(result));
		}
	};

	//----------------------------------------------------------------------
	//	install checks on form
	//----------------------------------------------------------------------
	//	seperate function because closure of fields[]
	//----------------------------------------------------------------------

	var installChecks = function(form) {

		var fields = [];

		for (var e=0; e<form.elements.length; e++) {

			var element = form.elements[e];

			switch (element.tagName.toLowerCase()) {

			case 'input':
			case 'textarea':

				var result = document.createElement('div');
				element.parentElement.insertBefore(result, element.nextSibling);

				fields.push(element);

				element.onchange  = checkInput;
				element.onblur    = checkInput;
				element.onkeydown = clearResult;

				continue;

			case 'button':

				switch (element.type) {

				case 'reset':

					element.onclick = function() {

						for (var i in fields) { fields[i].onkeydown(); }
						return true;
					};

					break;

				case 'button':

					element.onclick = function() {

						for (var i in fields) { fields[i].onblur(); }
						return false;
					};

					continue;
				}
			}
		}
	};

	//----------------------------------------------------------------------
	//	lookup form.nazicheck-container and install checks on tem
	//----------------------------------------------------------------------

	var containers = document.getElementsByClassName('nazicheck-container');

	for (var c=0; c<containers.length; c++) {

		var container = containers[c];
		if (container.elements) installChecks(container);
	}

	//----------------------------------------------------------------------
	//	fill input and start check from link in text
	//----------------------------------------------------------------------

	var elements = document.getElementsByTagName('a');

	for (var e=0; e<elements.length; e++) {

		var element = elements[e];

		var fieldId = element.getAttribute('data-nazicheck-field-id');
		if (!fieldId) continue;

		element.onclick = function(evt) {

			var targetId = this.getAttribute('data-nazicheck-field-id');
			var target   = document.getElementById(targetId);
			var value    = this.getAttribute('data-nazicheck-value');

			target.value = value;
			if (!target.onblur) return false;

			target.onblur();
			location.hash = targetId;

			return false;
		};

		element.setAttribute ('href', '#');
	}

});

//------------------------------------------------------------------------------
//	$Id: nazicheck.js,v 1.10 2018/02/06 15:38:16 wolf Exp $
//------------------------------------------------------------------------------
